==> ac-6.x-1.0.tar.gz: ac/ac.js <==
// $Id: ac.js,v 1.1 2008/08/11 17:42:34 tjholowaychuk Exp $

var AC = AC || {};

/**
 * Send an ajax request.
 *
 * @param string module
 *   Module name
 *
 * @param string op
 *   Operation
 *
 * @param object data
 *   (optional) Key:value pairs used to generate query string.
 *   When omitted this will be considered the callback function.
 *
 * @param function callback
 *   Callback function once request is complete.
 */
AC.request = function(module, op, data, callback) { 
  var d = typeof data == 'function' ? {} : data;
  var c = typeof data == 'function' ? data : callback;
  var u = Drupal.settings.basePath + 'js/' + module + '/' + op;
          
  d.token = Drupal.settings.ac.token;
  $.getJSON(u, d, function(response){
    c(response);
  });
};

/**
 * Validate response.
 *
 * @param object response
 *
 * @return bool
 */
AC.checkResponse = function(response) {
  var s = false;
           
  // Status failure
  if (!response.status){
    AC.setMessage(response.message_wrapper, response.message, 'error', response.message_duration);  
  }
  // Success
  else {   
    if (response.message.length){
      AC.setMessage(response.message_wrapper, response.message, 'status', response.message_duration);  
    }
    
    s = true;
  }
  
  return s;
};

/**
 * Set message.
 *
 * @param string wrapper
 *
 * @param string message
 *
 * @param string type
 *  (optional) Defaults to 'status'.
 *
 * @param int duration
 *  (optional) Message duration. Defaults to 3000;
 */
AC.setMessage = function(wrapper, message, type, duration) {
  var d = duration == null ? 3000 : duration; 
  var t = type || 'status';
                           
  $(wrapper).html('<div class="messages ac-message ' + t + '">' + message + '</div>');
  
  if (d){        
    setTimeout('AC.clearMessages()', d);
  }
};

/**
 * Clear messages set by AC.
 */
AC.clearMessages = function() {
  $('.ac-message').fadeOut(600);
};

==> ac-6.x-1.2.tar.gz: ac/ac.js <==
// $Id: ac.js,v 1.2 2008/08/15 20:50:15 tjholowaychuk Exp $

var AC = AC || {};

/**
 * Send an ajax request.
 *
 * @param string module
 *   Module name
 *
 * @param string op
 *   Operation
 *
 * @param object data
 *   (optional) Key:value pairs used to generate query string.
 *   When omitted this will be considered the callback function.
 *
 * @param function callback
 *   Callback function once request is complete.
 */
AC.request = function(module, op, data, callback) { 
  var d = typeof data == 'function' ? {} : data;
  var c = typeof data == 'function' ? data : callback;
  var u = Drupal.settings.basePath + 'js/' + module + '/' + op;
          
  d.token = Drupal.settings.ac.token;
  $.getJSON(u, d, function(response){
    c(response);
  });
};

/**
 * Validate response.
 *
 * @param object response
 *
 * @return bool
 */
AC.checkResponse = function(response) {
  var s = false;
  
  // Check debugging js         
  if (response.debug) {
    eval(response.debug);
  }
  // Status failure
  else if (!response.status){
    AC.setMessage(response.message_wrapper, response.message, 'error', response.message_duration);  
  }
  // Success
  else {   
    if (response.message.length){
      AC.setMessage(response.message_wrapper, response.message, 'status', response.message_duration);  
    }
    s = true;
  }
  
  return s;
};

/**
 * Set message.
 *
 * @param string wrapper
 *
 * @param string message
 *
 * @param string type
 *  (optional) Defaults to 'status'.
 *
 * @param int duration
 *  (optional) Message duration. Defaults to 3000;
 */
AC.setMessage = function(wrapper, message, type, duration) {
  var d = duration == null ? 3000 : duration; 
  var t = type || 'status';
                           
  $(wrapper).html('<div class="messages ac-message ' + t + '">' + message + '</div>');
  
  if (d){        
    setTimeout('AC.clearMessages()', d);
  }
};

/**
 * Clear messages set by AC.
 */
AC.clearMessages = function() {
  $('.ac-message').fadeOut(600);
};
